import re

class MDConfigReader(object):
    """
    MDConfigReader implements an interface for bitbone-style
    configuration files with a syntax like
            key = value
    """
    def __init__(self, defaults=None):
        """
        Constructor
        """
        self.data = defaults or {}

    def read(self, filename):
        """
        Reads a config file and stores the result for later retrieval.

        @param str filename
        """
        self.filename = filename
        self.filehandle = open(filename, 'rb')

        for line in self.filehandle.readlines():
            try:
                key, value = re.split('\s*=\s*', line.strip(), 1)
            except ValueError:
                # ignore unreadable lines
                # (often empty, sometimes malformed)
                continue
            self.data[key] = value
        self.filehandle.close()

    def __getitem__(self, key):
        """
        Returns the requested config value

        @param str key
        @return str value
        """
        return self.data[key]

    def __setitem__(self, key, value):
        """
        Updates the requested config value

        @param str key
        @param str value
        """
        self.data[key] = value

    def get(self, key, default=None):
        """
        Returns the requested config value

        ... but will not raise in exception if the key
        does not exist. Instead, the default value will
        be returned.

        @param str key
        @param mixed default
        @return str value
        """
        if key in self.data:
            return self.data[key]
        return default

# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
