class Deferred(object):
    """
    Deferred, a callback manager

    Objects of this class are mainly useful as function return values.

    Functions can return Deferred objects and the caller can subscribe
    to the object using .callback().
    The creating object then later executes the Deferred, also invoking
    all associated callbacks.
    """
    called = False

    def __init__(self):
        """Constructor"""
        self.callbacks = []

    def callback(self, callback):
        """
        Adds a new callback

        @param callable callback
        """
        self.callbacks.append(callback)

    def __call__(self, *args, **kwargs):
        """
        Executes all registered callbacks

        Arguments are passed as-is to the callbacks
        """
        self.called = True
        for callback in self.callbacks:
            callback(*args, **kwargs)

# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
