from __future__ import absolute_import
from email.generator import Generator
from email.header import Header, decode_header, make_header

# from python-2.7.9 stdlib, verbatim; required as this function is
# not exposed
def _is8bitstring(s):
    if isinstance(s, str):
        try:
            unicode(s, 'us-ascii')
        except UnicodeError:
            return True
    return False

# Lower-case list of headers which are commonly displayed by mail client
# software and should as such not be mangled with in regards to inserting
# arbitrary spaces.
visible_headers = ('subject', 'from', 'to', 'cc', 'sender')

# This class provides a patched version of stdlib's email.generator.Generator
# with the a patch for issue8769, a header encoding issue, which occurs
# with long, umlaut-containing and semicolon or comma containing subject
# lines.
# http://bugs.python.org/issue8769
class Generator(Generator):
    # _write_headers has been taken from the stdlib, but patched with the
    # fix from issue8769; it is also patched to avoid arbitrarily inserting
    # whitespace after semicolons or commas in user-visible headers
    def _write_headers(self, msg):
        for h, v in msg.items():
            print >> self._fp, '%s:' % h,
            if self._maxheaderlen == 0:
                # Explicit no-wrapping
                print >> self._fp, v
            elif isinstance(v, Header):
                # Header instances know what to do
                print >> self._fp, v.encode()
            elif _is8bitstring(v):
                # If we have raw 8bit data in a byte string, we have no idea
                # what the encoding is.  There is no safe way to split this
                # string.  If it's ascii-subset, then we could do a normal
                # ascii split, but if it's multibyte then we could break the
                # string.  There's no way to know so the least harm seems to
                # be to not split the string and risk it being too long.
                print >> self._fp, v
            else:
                # Header's got lots of smarts, so use it.  Note that this is
                # fundamentally broken though because we lose idempotency when
                # the header string is continued with tabs.  It will now be
                # continued with spaces.  This was reversedly broken before we
                # fixed bug 1974.  Either way, we lose.
                kwargs = {}
                if h.lower() in visible_headers:
                    # splitchars defaults to ';,' and attemtps to line-break
                    # after commas or semicolons; while this works nicely
                    # for technical headers such as Content-Type, it may
                    # insert unwanted, user-visible space characters after
                    # semicolons or commas; this avoids it:
                    kwargs['splitchars'] = ''

                hdr = make_header(decode_header(v),
                    maxlinelen=self._maxheaderlen, header_name=h)
                encoded = hdr.encode(**kwargs)
                # The following conversion is necessary to avoid an error
                # in py2.6 as encoded may still be a unicode object in some
                # cases. Due to that, some writes to self._fp would then
                # be unicode and some would be strings. This causes
                # UnicodeErrors in StringIO().getvalue() which we use outside.
                # This call should be safe as the encoding process should
                # guarantee the content to be ascii-only.
                encoded = str(encoded)
                print >> self._fp, encoded
        # A blank line always separates headers from body
        print >> self._fp
# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
