import re
import cgi
import logging
from functools import partial
from operator import itemgetter

logger = logging.getLogger(__name__)

def get_pattern_for(type):
    if type == 'html':
        return re.compile(r'(.*?)\$\{([a-zA-Z:]+)\}(\s*<br ?/?>\r?\n?)?')
    else:
        return re.compile(r'(.*?)\$\{([a-zA-Z:]+)\}(\r?\n?)')

class Template(object):
    """
    Substitutes template markers (like ${FULLNAME}) in the given
    text with real data and returns the result.
    """

    def use_data(self, context):
        """
        Sets the template data

        @param dict context {KEYWORD: value}
        """
        self.context = context

    def get_necessary_keys_for(self, type, text):
        """
        Returns a list of all used template markers, so that a
        prepopulated data object can be passed in by the user.

        @param str type [txt|html]
        @param str text to be analyzed
        """
        pattern = get_pattern_for(type)
        return map(itemgetter(1), re.findall(pattern, text))

    def process(self, type, text):
        """
        Does the actual work and returns the manipulated text.

        @param str type
        @param str text to be worked on
        @return text
        """
        pattern = get_pattern_for(type)
        return re.sub(pattern, partial(self._substitution_callback, type),
                text)

    def _substitution_callback(self, type, matches):
        """Will be called by the regular expression substitution"""
        prefix = matches.group(1)
        key = matches.group(2).lower()
        ws = matches.group(3) or ''

        if key not in self.context:
            logger.debug("Using undefined template marker ${%s}" % key)
        elif self.context[key]:
            value = self.context[key]
            if type == 'html':
                value = cgi.escape(value).encode('ascii',
                        'xmlcharrefreplace')
            return prefix + value + ws

        if prefix:
            return prefix + ws

        return ''

# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
