import socket
from logging.handlers import SysLogHandler

class DummyCallable(object):
    """
    Just a dummy which can be called, does nothing and returns None
    """
    def __call__(self, *args, **kwargs):
        return

class FaultTolerantSysLogHandler(object):
    """
    A wrapper around logging.handlers.SysLogHandler which
    *silently* discards socket errors.
    This is ok for us; if we used UDP syslog addresses, we would
    have no way to check for successful delivery anyway.
    Also, a failure to contact syslog should not lead to the daemon
    crashing.
    """
    def __init__(self, *args, **kwargs):
        self._handler = self._handle_errors(
            SysLogHandler, *args, **kwargs)

    def _handle_errors(self, callable, *args, **kwargs):
        try:
            return callable(*args, **kwargs)
        except socket.error:
            # silently ignore socket.errors
            pass

    def __getattr__(self, key):
        """
        Proxy
        """
        if not self._handler:
            # __init__ already failed? then we do not even attempt
            # to use our handler instance (which would be None)
            # instead we return a dummy callable
            return DummyCallable()
        return getattr(self._handler, key)

# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
