import unittest
import random
from bitbone.accounts.ldap_id_handlers import (
    make_id_handler, SidHandler, GuidHandler, PlainIdHandler)

class TestPlainHandler(unittest.TestCase):
    def test_make(self):
        h = make_id_handler('uid', 'text')
        self.failUnless(isinstance(h, PlainIdHandler))

    def test_to_string(self):
        p = PlainIdHandler()
        self.assertEquals(p.to_string("1234"), "1234")

    def test_to_bin(self):
        p = PlainIdHandler()
        self.assertEquals(p.to_bin("1234"), "1234")


class TestSidHandler(unittest.TestCase):
    def test_make(self):
        h = make_id_handler('objectSID', 'binary')
        self.failUnless(isinstance(h, SidHandler))

    def test_to_bin(self):
        s = SidHandler()
        self.assertEquals(s.to_bin(
            "S-1-5-21-1082428380-366998223-2307430412-1124"),
            "AQUAAAAAAAUVAAAA3IuEQM/y3xUMmIiJZAQAAA==".decode("base64"))

    def test_to_string(self):
        s = SidHandler()
        self.assertEquals(s.to_string(
            "AQUAAAAAAAUVAAAA3IuEQM/y3xUMmIiJZAQAAA==".decode("base64")),
            "S-1-5-21-1082428380-366998223-2307430412-1124")

    def test_random(self):
        g = SidHandler()
        bin_sid = '\x01\x05' + ''.join(
            [chr(random.randint(0, 255)) for x in xrange(26)])
        str_sid = g.to_string(bin_sid)
        new_bin_sid = g.to_bin(str_sid)
        self.assertEquals(bin_sid, new_bin_sid)


class TestGuidHandler(unittest.TestCase):
    def test_make(self):
        h = make_id_handler('objectGUID', 'binary')
        self.failUnless(isinstance(h, GuidHandler))

    def test_to_string(self):
        g = GuidHandler()
        self.assertEquals(g.to_string(
            "8zBZiUNbyk2caMxDp02t5A==".decode("base64")),
            "895930f3-5b43-4dca-9c68-cc43a74dade4"
        )

    def test_to_bin(self):
        g = GuidHandler()
        self.assertEquals(g.to_bin(
            "895930f3-5b43-4dca-9c68-cc43a74dade4"),
            "8zBZiUNbyk2caMxDp02t5A==".decode("base64"))

    def test_random(self):
        g = GuidHandler()
        bin_guid = ''.join(
            [chr(random.randint(0, 255)) for x in xrange(16)])
        str_guid = g.to_string(bin_guid)
        new_bin_guid = g.to_bin(str_guid)
        self.assertEquals(bin_guid, new_bin_guid)


# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
