import os
import shutil
import unittest
from tempfile import mkdtemp
from bitbone.config import MDConfigReader

class TestMDConfigReader(unittest.TestCase):
    def setUp(self):
        self.tmpdir = mkdtemp()

    def tearDown(self):
        if self.tmpdir != '/' and '..' not in self.tmpdir:
            shutil.rmtree(self.tmpdir)

    def test_file(self):
        path = os.path.join(self.tmpdir, 'test.cfg')
        fd = open(path, 'wb')
        fd.write("some_config_option = fooBarBaz\n")
        fd.write("yet_another_option =   lots of space \n")
        fd.write("and another one =like'that'")
        fd.close()
        ycr = MDConfigReader()
        ycr.read(path)
        self.assertEquals(ycr['some_config_option'], 'fooBarBaz')
        self.assertEquals(ycr['yet_another_option'], 'lots of space')
        self.assertEquals(ycr['and another one'], "like'that'")
        self.assertRaises(KeyError, lambda: ycr['non existant'])

    def test_tolerance(self):
        path = os.path.join(self.tmpdir, 'test.cfg')
        fd = open(path, 'wb')
        fd.write("\n") # empty line
        fd.write("malformed_line\n")
        fd.write("should still work = yes")
        fd.close()
        ycr = MDConfigReader()
        ycr.read(path)
        self.assertEquals(ycr['should still work'], 'yes')

    def test_get(self):
        path = os.path.join(self.tmpdir, 'test.cfg')
        fd = open(path, 'wb')
        fd.write("some_config_option = fooBarBaz\n")
        fd.write("yet_another_option =   lots of space \n")
        fd.write("and another one =like'that'")
        fd.close()
        ycr = MDConfigReader()
        ycr.read(path)
        self.assertEquals(ycr.get('some_config_option'), 'fooBarBaz')
        self.assertEquals(ycr.get('yet_another_option', 'xx'), 'lots of space')
        self.assertEquals(ycr.get('non-existant', 'xx'), "xx")
        self.assertEquals(ycr.get('non-existant2'), None)

    def test_set(self):
        ycr = MDConfigReader()
        ycr['test'] = 1
        self.assertEquals(ycr['test'], 1)



# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
