import unittest
import shutil
import os
from tempfile import mkdtemp
from ...postfix import PostfixConfigReader

class TestPostfixConfigReader(unittest.TestCase):
    def setUp(self):
        self.tmpdir = mkdtemp()

    def tearDown(self):
        if self.tmpdir != '/' and '..' not in self.tmpdir:
            shutil.rmtree(self.tmpdir)

    def test(self):
        path = os.path.join(self.tmpdir, 'main.cf')
        fd = open(path, 'wb')
        fd.write("""
mynetworks = [::1]/128, [::ffff:127.0.0.0]/104, 127.0.0.0/8
virtual_mailbox_domains = localhost, bitbone.de
virtual_mailbox_maps = ldap:/etc/postfix/ldap-users.cf
virtual_alias_maps = regexp:/etc/postfix/virtual_users_global, ldap:/etc/postfix/ldap-aliases.cf, ldap:/etc/postfix/ldap-group.cf
""")
        fd.close()
        pc = PostfixConfigReader()
        pc.read(path)
        self.assertEquals(pc.get_local_domains(),
                ["localhost", "bitbone.de"])

    def test_empty(self):
        path = os.path.join(self.tmpdir, 'main.cf')
        fd = open(path, 'wb')
        fd.write("""
mynetworks = [::1]/128, [::ffff:127.0.0.0]/104, 127.0.0.0/8
virtual_mailbox_maps = ldap:/etc/postfix/ldap-users.cf
virtual_alias_maps = regexp:/etc/postfix/virtual_users_global, ldap:/etc/postfix/ldap-aliases.cf, ldap:/etc/postfix/ldap-group.cf
""")
        fd.close()
        pc = PostfixConfigReader()
        pc.read(path)
        self.assertEquals(pc.get_local_domains(),
                [])

# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
