import unittest
from ....smtp.helpers import parse_address, encode_message, decode_message

class TestParseAddress(unittest.TestCase):
    def test_simple(self):
        self.assertEquals(
            parse_address("to:", "TO:test@example.org ARG1 ARG2"),
            ("test@example.org", ["ARG1", "ARG2"]))

    def test_empty(self):
        self.assertEquals(
            parse_address("from:", "FROM:<>"), ("", []))

    def test_simple_space(self):
        self.assertEquals(
            parse_address("to:", "TO: test@example.org ARG1 ARG2"),
            ("test@example.org", ["ARG1", "ARG2"]))

    def test_angle_brackets(self):
        self.assertEquals(
            parse_address("to:", "TO:<test@example.org> ARG1 ARG2"),
            ("test@example.org", ["ARG1", "ARG2"]))

    def test_angle_brackets_space(self):
        self.assertEquals(
            parse_address("to:", "TO: <test@example.org> ARG1 ARG2"),
            ("test@example.org", ["ARG1", "ARG2"]))

    def test_quotes(self):
        self.assertEquals(
            parse_address("to:", 'TO:<"<test"@example.org> ARG1 ARG2'),
            ("<test@example.org", ["ARG1", "ARG2"]))

    def test_backslash(self):
        self.assertEquals(
            parse_address("to:", r'TO:<\t\e\s\t@\e\x\amp\le.org> ARG1'),
            ("test@example.org", ["ARG1"]))

    def test_backslash_space(self):
        self.assertEquals(
            parse_address("to:",
                r'TO:<test\ @example.org> ARG1\ STILL\ ARG1'),
            ("test @example.org", ["ARG1 STILL ARG1"]))

    def test_quoted_space(self):
        self.assertEquals(
            parse_address("to:",
                r'TO:<"test "@example.org> "ARG1 STILL ARG1"'),
            ("test @example.org", ["ARG1 STILL ARG1"]))

    def test_quoted_backslash_space(self):
        self.assertEquals(
            parse_address("to:",
                r'TO:<"test\ "@example.org> "ARG1\ STILL\ \ARG1"'),
            ("test @example.org", ["ARG1 STILL ARG1"]))

    def test_routed(self):
        self.assertEquals(
            parse_address("to:",
                r'TO:<@gw1.example.org,@gw2.example.org:'
                r'someone@example.org> arg1 2 3'),
            ("someone@example.org", ["arg1", "2", "3"]))


class TestDecodeMessage(unittest.TestCase):
    def test(self):
        self.assertEquals(decode_message("abc"), "abc")

    def test_single_dot(self):
        self.assertEquals(decode_message("abc\r\n..\r\ndef"),
            "abc\r\n.\r\ndef")

	def test_single_dot_after_lf(self):
		self.assertEquals(decode_message("abc\n.\ndef"),
			"abc\n.\ndef")


class TestEncodeMessage(unittest.TestCase):
    def test(self):
        self.assertEquals(encode_message("abc"), "abc")

    def test_single_dot(self):
        self.assertEquals(encode_message("abc\r\n.\r\ndef"),
            "abc\r\n..\r\ndef")

	def test_single_dot_after_lf(self):
		self.assertEquals(encode_message("abc\n.\ndef"),
			"abc\n.\ndef")

# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
