import unittest
import time
import uuid
import os
from bitbone.utils.license import License

class TestLicense(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        f = open("systemid", "w")
        f.write(str(uuid.uuid4()))
        f.close()

    @classmethod
    def tearDownClass(cls):
        os.unlink("systemid")

    def test_read_not_exists(self):
        license = License(key_file="bitbone/tests/bitbone/utils/samples/not_exists.key", gpg_home="")
        self.assertFalse(bool(license.read_key()))

    def test_read_valid(self):
        license = License(key_file="bitbone/tests/bitbone/utils/samples/valid.key", gpg_home="bitbone/tests/bitbone/utils/samples/gnupg")
        self.assertTrue(bool(license.read_key()))
        self.assertTrue(license.is_valid())

    def test_read_invalid(self):
        license = License(key_file="bitbone/tests/bitbone/utils/samples/invalid.key", gpg_home="bitbone/tests/bitbone/utils/samples/gnupg")
        self.assertFalse(bool(license.read_key()))

    def test_read_invalid_sign(self):
        license = License(key_file="bitbone/tests/bitbone/utils/samples/invalid-sign-key.key", gpg_home="bitbone/tests/bitbone/utils/samples/gnupg")
        self.assertFalse(bool(license.read_key()))

    def test_trial_invalid_version(self):
        license = License(key_file="bitbone/tests/bitbone/utils/samples/invalid_version.key", gpg_home="bitbone/tests/bitbone/utils/samples/gnupg")
        self.assertFalse(license.is_valid())

    def test_trial_valid_version2(self):
        license = License(key_file="bitbone/tests/bitbone/utils/samples/valid-trial-version-2.key", gpg_home="bitbone/tests/bitbone/utils/samples/gnupg")
        self.assertTrue(license.is_valid())

    def test_create_new_cache(self):
        license = License(key_file="bitbone/tests/bitbone/utils/samples/valid.key", gpg_home="bitbone/tests/bitbone/utils/samples/gnupg")
        license.read_key()
        ts1 = license.key_refresh_time
        license.read_key()
        ts2 = license.key_refresh_time
        license.read_key(force=True)
        ts3 = license.key_refresh_time

        self.assertEqual(ts1, ts2)
        self.assertNotEqual(ts1, ts3)

    def test_get_version(self):
        license = License(key_file="bitbone/tests/bitbone/utils/samples/valid.key", gpg_home="bitbone/tests/bitbone/utils/samples/gnupg")
        self.assertRegexpMatches(license.get_version(), "^\d+$")

    def test_get_installdate(self):
        license = License(key_file="bitbone/tests/bitbone/utils/samples/valid.key", gpg_home="bitbone/tests/bitbone/utils/samples/gnupg")
        self.assertLess(license.get_install_time(), time.time())

    def test_report_valid(self):
        license = License(key_file="bitbone/tests/bitbone/utils/samples/valid-trial-version-2.key", gpg_home="bitbone/tests/bitbone/utils/samples/gnupg")
        license.read_key()

        license.install_time = time.time() - license.seconds_from_days(25)
        self.assertEqual(license.report(), license.LICENSE_WARNING % 5)

        license.install_time = time.time() - license.seconds_from_days(26)
        self.assertEqual(license.report(), license.LICENSE_WARNING % 4)

        license.install_time = time.time() - license.seconds_from_days(30)
        self.assertEqual(license.report(), license.LICENSE_EXPIRED)

        license.install_time = time.time() - license.seconds_from_days(31)
        self.assertEqual(license.report(), license.LICENSE_EXPIRED)


# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
