#!/usr/bin/env python
from smtplib import SMTP
from time import time
from multiprocessing import Pool
from optparse import OptionParser
from functools import partial
from email.utils import formatdate as rfc2822_date


def send_mail(smtp_host, smtp_port, mail_from, mail_to, mail_text, idx):
    s = SMTP(host=smtp_host, port=smtp_port)
    s.sendmail(mail_from, [mail_to], mail_text.replace('{IDX}', str(idx)))
    print "."
    s.close()

if __name__ == '__main__':
    mail_text = (
        'Subject: Test-Mail {IDX}\r\n'
        'Date: %s\r\n\r\n'
        'Testmail\r\n') % rfc2822_date()
    html_mail_text = (
        'Subject: Test-Mail {IDX}\r\n'
        'Date: %s\r\n'
        'Content-Type: text/html\r\n\r\n'
        '<html><body>\r\n'
        '<b>HTML-</b>Testmail</body></html>\r\n') % rfc2822_date()
    parser = OptionParser()
    parser.add_option("-o", "--host", dest="host",
        default="127.0.0.1")
    parser.add_option("-p", "--port", dest="port",
        default=25, type='int')
    parser.add_option("-t", "--threads", dest="threads",
        type="int", default=1)
    parser.add_option("-n", "--num-mails", dest="num_mails",
        type="int", default=10)
    parser.add_option("-f", "--mail-from", dest="mail_from",
        default="tester@example.org")
    parser.add_option("-r", "--mail-to", dest="mail_to",
        default="test@localhost")
    parser.add_option("-m", "--mail-text", dest="mail_text",
        default=mail_text)
    parser.add_option("--html", action="store_true", default=False)
    options, args = parser.parse_args()
    if options.html and options.mail_text == mail_text:
        options.mail_text = html_mail_text

    options.mail_text = (
        'From: %s\r\n'
        'To: %s\r\n'
    ) % (options.mail_from, options.mail_to) + options.mail_text
    print "Will send %d mails" % options.num_mails
    starttime = time()
    pool = Pool(options.threads)
    send_mail_with_args = partial(
        send_mail,
        options.host,
        options.port,
        options.mail_from,
        options.mail_to,
        options.mail_text
    )
    pool.map(send_mail_with_args, xrange(options.num_mails))
    endtime = time()
    print "Sent %d mails in %f seconds" % (
        options.num_mails, endtime - starttime)

# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
