#! /usr/bin/python
import pwd
import grp
from bitbone.daemonize import Daemon
from postfix_disclaimers_cf import Main

class DaemonizingMain(Main):
    def make_optparser(self):
        Main.make_optparser(self)
        self.parser.add_option('--log-file',
            help="path to the file where log messages are written to")
        self.parser.add_option('--user',
            help="name of the filter user (for dropping permissions)")
        self.parser.add_option('--group',
            help="name of the filter grup (for dropping permissions)")
        self.parser.add_option('--pid-file',
            default="/var/run/maildisclaimer.pid",
            help="path to the file where the process id will be written to")


    def make_daemon(self):
        if not self.options.pid_file:
            self.parser.error('--pid-file is required')

        uid = gid = None
        if self.options.user:
            try:
                user = pwd.getpwnam(self.options.user)
                uid = user.pw_uid
                gid = user.pw_gid
            except KeyError:
                self.parser.error('invalid user %s' % self.options.user)

        if self.options.group:
            try:
                group = grp.getgrnam(self.options.group)
                gid = group.gr_gid
            except KeyError:
                self.parser.error('invalid group %s' % self.options.group)

        self.daemon = Daemon(pidfile=self.options.pid_file,
            stdout=self.options.log_file, stderr=self.options.log_file,
            uid=uid, gid=gid)

    def handle_args(self):
        if self.args:
            if self.args[0] == 'stop':
                return self.daemon.stop()
            elif self.args[0] == 'restart':
                return self.daemon.restart()
            elif self.args[0] == 'status':
                return self.daemon.status()

    def run(self):
        self.daemon.start()
        Main.run(self)

if __name__ == '__main__':
    m = DaemonizingMain()
    m.make_optparser()
    m.parse_arguments()
    m.make_daemon()
    m.handle_args()
    m.make_content_filter()
    m.run()

# This file is subject to the terms and conditions defined in
# file 'LICENSE.txt', which is part of this source code package.
#
# Copyright (C) 2015 bitbone AG
